@@ -4,10 +4,29 @@ from tqdm.auto import tqdm
 from tqdm.utils import CallbackIOWrapper
 
 from .base import Base
-from .utils import check
+from .utils import check, dataset
 class DatasetManager(Base):
 
     def upload_file(self, directory_id=None, file_path=None, description="", lineage=None):
+        """_summary_
+
+        Args:
+            directory_id (_type_, optional): _description_. Defaults to None.
+            file_path (_type_, optional): _description_. Defaults to None.
+            description (str, optional): _description_. Defaults to "".
+            lineage (_type_, optional): _description_. Defaults to None.
+
+        Raises:
+            Exception: _description_
+            Exception: _description_
+            Exception: _description_
+            Exception: _description_
+            Exception: _description_
+            Exception: _description_
+
+        Returns:
+            _type_: _description_
+        """
         if type(file_path) != str :
             raise Exception(f"file_path expect `str` but got {type(file_path)}, or please input `file_path='<path>'`")
         elif not os.path.exists(file_path):
@@ -49,7 +68,7 @@ class DatasetManager(Base):
         if _res.status_code == 200:
             _uploaded = True
         else:
-            print(_res.content.decode())
+            if self._verbose: print(_res.content.decode())
             raise Exception("Some thing wrong with datastore")
         data.update({
             'uploaded': _uploaded,
@@ -81,6 +100,21 @@ class DatasetManager(Base):
         return data
     
     def download_file(self, file_id=None, download_path=None):
+        """_summary_
+
+        Args:
+            file_id (_type_, optional): _description_. Defaults to None.
+            download_path (_type_, optional): _description_. Defaults to None.
+
+        Raises:
+            Exception: _description_
+            Exception: _description_
+            Exception: _description_
+            Exception: _description_
+
+        Returns:
+            _type_: _description_
+        """
         if file_id == None:
              raise Exception("please input file_id")
         _res = requests.get(f"{self._discovery_api}/file/{file_id}/",  headers=self._jwt_header)
@@ -105,7 +139,7 @@ class DatasetManager(Base):
             
         
         total_size_in_bytes= int(_res.headers.get('content-length', 0))
-        print(total_size_in_bytes)
+        if self._verbose: print(f"total size : {total_size_in_bytes} B")
         block_size = 1024 #1 Kibibyte
         progress_bar = tqdm(total=total_size_in_bytes, unit='iB', unit_scale=True)
         
@@ -119,4 +153,54 @@ class DatasetManager(Base):
             'download_sucess': os.path.exists(f_path),
             'f_path': f_path
         })
-        return meta
\ No newline at end of file
+        return meta
+    
+    def createDataset(self, name=None, tags=None):
+        """_summary_
+
+        Args:
+            name (_type_, optional): _description_. Defaults to None.
+            tags (_type_, optional): _description_. Defaults to None.
+
+        Returns:
+            _type_: _description_
+        """
+        check.check_type(variable=name, variableName="name", dtype=str)
+        check.check_type(variable=tags, variableName="tags", dtype=list, child=str)
+        
+        tags_ids = dataset.get_tag_ids(base_uri=self._base_discovery_api, tags=tags, header=self._jwt_header)
+        
+        r = requests.post(f"{self._base_discovery_api}/api/v2/dataset/", headers=self._jwt_header,
+                          json={
+                              'name': name,
+                              'title': name,
+                              'tag': tags_ids
+                          }
+        )
+        check.check_http_status_code(response=r)
+        return r.json()
+    
+    def createDirectory(self, directory_id=None, name=None, description=None):
+        """_summary_
+
+        Args:
+            directory_id (_type_, optional): _description_. Defaults to None.
+            name (_type_, optional): _description_. Defaults to None.
+            description (_type_, optional): _description_. Defaults to None.
+
+        Returns:
+            _type_: _description_
+        """
+        check.check_type(variable=directory_id, variableName="directory_id", dtype=int)
+        check.check_type(variable=name, variableName="name", dtype=str)
+        check.check_type(variable=description, variableName="description", dtype=str)
+        
+        r = requests.post(f"{self._base_discovery_api}/api/v2/directory/", headers=self._jwt_header,
+                          json={
+                              "name": name,
+                              "description": description,
+                              "parent_dir": directory_id
+                          }
+        )
+        check.check_http_status_code(response=r)
+        return r.json()
\ No newline at end of file
